module.exports = defineTest({
	description: 'retains side-effects in declarations will tree-shaking the declared variable'
});
